// MotorBrake.ino
// ftDuino-Experiment zum Bremsverhalten von Elektromotoren

// == インクルード 必要ファイルの読み込み ==
#include <Ftduino.h>

void setup() {
  pinMode(LED_BUILTIN, OUTPUT); // 内部LED -- 出力
  digitalWrite(LED_BUILTIN, HIGH); // 内部LED - ON

  // シリアル通信
  Serial.begin(115200);  // 115200bpsでシリアルポートを開きます
  while (!Serial);

  ftduino.init();
}

void loop() {
  static uint32_t last_led_event = 0;
  // LEDを1秒ごとに点滅
  if ((millis() - last_led_event) >= 1000) { // 1秒を超えたら
    digitalWrite(LED_BUILTIN, HIGH);    // LED - ON
    last_led_event = millis(); // 時間を変数へ格納

  } else if ((millis() - last_led_event) > 50)// 50msを超えたら
    digitalWrite(LED_BUILTIN, LOW);     // LED - OFF

  // 5秒ごとにモーターテストを開始
  static uint32_t last_motor_event = 0;
  if (((millis() - last_motor_event) > 5000)) { // 5秒を超えたら
    static bool brake = true;

    last_motor_event = millis();  // 時間を変数へと格納

    // エンコーダーモーターのブレーキの設定
    ftduino.motor_counter_set_brake(Ftduino::M1, brake);

    /*
      Der TXT-Encoder-Motor liefert 63 1/3 Impulse pro Umdrehung,190 Impulse sind demnach
      drei volle Umdrehungen
    */

    // motor_counter(ポート, モード, pwm, カウンター)
    ftduino.motor_counter(Ftduino::M1, Ftduino::LEFT, Ftduino::MAX, 190);

    //シリアルモニタへ出力
    Serial.println("エンジンM1　== 始動 ==");
    Serial.println("エンコーダーパルスを待っています...");

    //  エンコーダモーターカウンタの評価
    while (ftduino.motor_counter_active(Ftduino::M1));

    if (brake)
      Serial.println("モーターがアクティブブレーキをかけらています --オンラインを待ちます--");
    else
      Serial.println("エンジンを停止 --実行を待ちます --");

    delay(1000);//　1秒間停止

    Serial.print("カウンターステータス: ");
    // C1の カウンター入力のステータス読み取り
    Serial.print(ftduino.counter_get(Ftduino::C1));

    Serial.println("-- INPULSE －－");

    //ブレーキの有無にかかわらず交互にテスト
    // brakeを反転
    brake = !brake;
  }
}
